dataqol.classif: Questionnaire Responses Of Patients Affected By Breast Cancer

dataqol.classifR Documentation

Questionnaire Responses Of Patients Affected By Breast Cancer

Description

This dataset contains the responses of 40 patients to 30 questions about their quality of life. Furthermore, a variable indicates if the patient survived the disease.

Usage

dataqol.classif

Format

A dataframe with 40 lines and 32 columns. A line represents a patient and a column contains information about the patients.

Id

patient Id

q1-q28

responses to 28 questions with the number of levels equal to 4

q29-q30

responses to 22 questions with the number of levels equal to 7

death

if the patient survived (1) or not (2)

The table was determined based on data associated with the package available at: https://cran.r-project.org/package=QoLR


ordinalClust documentation built on April 22, 2026, 1:07 a.m.