predict: ~~ Method for the function 'predict' in the 'ordinalClust'...

predictR Documentation

~~ Method for the function predict in the ordinalClust package ~~

Description

Method for the function predict in the ordinalClust package.

Methods

signature(object = "ResultClassifOrdinal")

Use this method with the result of the function bosclassif, and a new sample to predict the classes.


ordinalClust documentation built on April 22, 2026, 1:07 a.m.