@VMatrix of dimension N*kr such that V[i,g]=1 if i belongs to cluster g.
@iclICL value for co-clustering.
@nameName of the result.
@paramschainList of length nbSEMburn. The parameters of the blocks are stored for each iteration of the SEM-Gibbs algorithm.
@pichainList of length nbSEM. Item i is a vector of length kr that contains the row mixing proportions at iteration i.
@rhochainList of length nbSEM. Item i is a list of length D whose d^th element contains the column mixing proportions of the group of variables d, for iteration i.
@zcList of length D. The d^th item is a vector of length J[d] representing the column partitions for the group of variables d.
@zrVector of length N with resulting row partitions.
@WList of length D. Item d is a matrix of dimension J*kc[d] such that W[j,h]=1 if j belongs to cluster h.
@mVector of length D. The d^th element represents the number of levels of d^th group of variables.
@paramsList of length D. The d^th item represents the blocks parameters for a group of variables d.
@piVector of length kr. This corresponds to the row mixing proportions.
@rhoList of length D. The d^th item represents the column mixing proportion for the d^th group of variables.
@xhatList of length D. The d^th item represents the dataset of the d^th group of variables, with missing values completed.
@zrchainMatrix of dimension nbSEM*N. Row i represents the row cluster partitions at iteration i.
@zrchainList of length D. Item d is a matrix of dimension nbSEM*J[d]. Row i represents the column cluster partitions at iteration i.