| pejSim | R Documentation |
This function computes the probabilty for a level ej to be sampled from a BOS distribution of parameters (mu,pi), with the number of levels equal to m. It can be used to generate data with a BOS distribution.
pejSim(ej,m,mu,p)
ej |
Levels to be sampled |
m |
Number of levels. |
mu |
mu parameter for BOS distribution. |
p |
pi parameter for BOS distribution. |
Returns the probability of ej to be sampled from a BOS distribution of parameters (mu,pi), with the number of levels equal to m.
Margot Selosse, Julien Jacques, Christophe Biernacki.
library(ordinalClust)
data("dataqol")
set.seed(5)
m=7
nr=10000
mu=5
pi=0.5
probaBOS=rep(0,m)
for (im in 1:m) probaBOS[im]=pejSim(im,m,mu,pi)
M <- sample(1:m,nr,prob = probaBOS, replace=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.